@@ -36,7 +36,7 @@ Lepl is a parser library written in Python.
   
 This is the API documentation; the module index is at the bottom of this page.  
 There is also a `manual <../index.html>`_ which gives a higher level
-overview. 
+overview.
 
 The home page for this package is the 
 `Lepl website <http://www.acooke.org/lepl>`_.
@@ -113,69 +113,83 @@ Running this gives the result::
 from lepl.contrib.matchers import SmartSeparator2
 from lepl.core.config import Configuration, ConfigBuilder
 from lepl.core.manager import GeneratorManager
-from lepl.core.trace import RecordDeepest, TraceResults
-from lepl.matchers.combine import And, Or, First
+from lepl.core.trace import RecordDeepest, TraceStack
+from lepl.matchers.combine import And, Or, First, Difference, Limit
 from lepl.matchers.core import Empty, Any, Delayed, Literal, Empty, \
-    Lookahead, PostMatch, Regexp
-from lepl.matchers.monitor import Trace, Commit
+    Lookahead, Regexp
+from lepl.matchers.complex import PostMatch, Columns, Iterate
+from lepl.matchers.monitor import Trace
 from lepl.matchers.derived import Apply, args, KApply, Join, \
     AnyBut, Optional, Star, ZeroOrMore, Map, Add, Drop, Repeat, Plus, \
     OneOrMore, Substitute, Name, Eof, Eos, Identity, Newline, Space, \
     Whitespace, Digit, Letter, Upper, Lower, Printable, Punctuation, \
     UnsignedInteger, SignedInteger, Integer, UnsignedFloat, SignedFloat, \
-    SignedEFloat, Float, Word, DropEmpty, Literals, String, SingleLineString, \
-    SkipString, SkipTo, Columns
+    UnsignedEFloat, SignedEFloat, Float, UnsignedReal, SignedReal, \
+    UnsignedEReal, SignedEReal, Real, Word, DropEmpty, Literals, \
+    String, SingleLineString, SkipString, SkipTo
 from lepl.matchers.error import Error, make_error, raise_error
 from lepl.matchers.memo import RMemo, LMemo, MemoException
 from lepl.matchers.operators import Override, Separator, SmartSeparator1, \
-    GREEDY, NON_GREEDY, DEPTH_FIRST, BREADTH_FIRST, DroppedSpace
+    GREEDY, NON_GREEDY, DEPTH_FIRST, BREADTH_FIRST, DroppedSpace, REDUCE
 from lepl.matchers.support import function_matcher, function_matcher_factory, \
     sequence_matcher, sequence_matcher_factory, \
     trampoline_matcher, trampoline_matcher_factory
-from lepl.matchers.transform import PostCondition
+from lepl.matchers.transform import PostCondition, Transform, Assert
 from lepl.matchers.variables import TraceVariables
-from lepl.lexer.matchers import Token, LexerError, RuntimeLexerError
-from lepl.offside.lexer import Indent, LineAwareEol, LineAwareSol, BIndent
-from lepl.offside.matchers import Line, Block, BLine, ContinuedLineFactory, \
-    ContinuedBLineFactory, Extend, SOL, EOL, rightmost, constant_indent
+from lepl.lexer.matchers import Token
+from lepl.lexer.support import LexerError, RuntimeLexerError
+from lepl.lexer.lines.matchers import Block, Line, LineStart, LineEnd, \
+    constant_indent, explicit, to_right, ContinuedLineFactory, Extend, \
+    NO_BLOCKS, DEFAULT_POLICY
 from lepl.regexp.core import RegexpError
 from lepl.regexp.matchers import NfaRegexp, DfaRegexp
 from lepl.regexp.unicode import UnicodeAlphabet
+from lepl.stream.core import s_debug, s_deepest, s_delta, s_empty, s_eq, \
+    s_factory, s_fmt, s_global_kargs, s_id, s_join, s_kargs, s_key, \
+    s_len, s_line, s_max, s_next, s_stream
 from lepl.stream.maxdepth import FullFirstMatchException
-from lepl.stream.stream import DEFAULT_STREAM_FACTORY
-from lepl.support.list import List, sexpr_fold, sexpr_throw
+from lepl.stream.factory import DEFAULT_STREAM_FACTORY
+from lepl.support.list import List, sexpr_fold, sexpr_throw, sexpr_flatten, \
+    sexpr_to_tree
 from lepl.support.node import Node, make_dict, join_with, node_throw
+from lepl.support.timer import print_timing
 
 __all__ = [
+           
         # lepl.core.config
         'Configuration',
         'ConfigBuilder',
+        
         # lepl.contrib.matchers
         'SmartSeparator2',
+        
         # lepl.matchers.error
         'make_error',
         'raise_error',
         'Error',
+        
         # lepl.matchers.core
         'Empty',
         'Repeat',
-        'And',
-        'Or',
         'Join',
-        'First',
         'Any',
         'Literal',
         'Empty',
         'Lookahead',
-        'PostMatch',
-        'Columns',
         'Regexp', 
+        
+        # lepl.matchers.combine
+        'And',
+        'Or',
+        'First',
+        'Difference',
+        'Limit',
+        
         # lepl.matchers.derived
         'Apply',
         'args',
         'KApply',
         'Delayed', 
-        'Commit', 
         'Trace', 
         'AnyBut', 
         'Optional', 
@@ -199,14 +213,26 @@ __all__ = [
         'Upper', 
         'Lower', 
         'Printable', 
-        'Punctuation', 
+        'Punctuation',
+         
         'UnsignedInteger', 
         'SignedInteger', 
-        'Integer', 
+        'Integer',
+         
+        # float matchers exclude integers
         'UnsignedFloat', 
         'SignedFloat', 
+        'UnsignedEFloat',
         'SignedEFloat', 
-        'Float', 
+        'Float',
+         
+        # real matchers match both floats and integers
+        'UnsignedReal', 
+        'SignedReal', 
+        'UnsignedEReal',
+        'SignedEReal', 
+        'Real',
+        
         'Word',
         'DropEmpty',
         'Literals',
@@ -218,6 +244,13 @@ __all__ = [
         'NON_GREEDY',
         'DEPTH_FIRST',
         'BREADTH_FIRST',
+        'REDUCE',
+        
+        # lepl.matchers.complex
+        'PostMatch',
+        'Columns',
+        'Iterate',
+
         # lepl.matchers.support
         'function_matcher', 
         'function_matcher_factory',
@@ -225,67 +258,104 @@ __all__ = [
         'sequence_matcher_factory',
         'trampoline_matcher', 
         'trampoline_matcher_factory',
+        
         # lepl.matchers.transform
         'PostCondition',
+        'Transform',
+        'Assert',
+        
         # lepl.matchers.variables
         'TraceVariables',
+        
         # lepl.stream.stream
         'DEFAULT_STREAM_FACTORY',
+        
         # lepl.matchers.operators
         'Override',
         'Separator',
         'SmartSeparator1',
         'DroppedSpace',
+        
         # lepl.support.node
         'Node',
         'make_dict',
         'join_with',
         'node_throw',
+        
         # lepl.support.list
         'List',
         'sexpr_fold',
         'sexpr_throw',
+        'sexpr_flatten',
+        'sexpr_to_tree',
+        
         # lepl.lexer.matchers
         'Token',
         'LexerError',
         'RuntimeLexerError',
+        
         # lepl.core.manager
         'GeneratorManager',
+        
         # lepl.core.trace
         'RecordDeepest',
-        'TraceResults',
+        'TraceStack',
+        
         # lepl.core.memo,
         'RMemo',
         'LMemo',
         'MemoException',
+        
         # lepl.regexp.core
         'RegexpError',
+        
         # lepl.regexp.matchers
         'NfaRegexp',
         'DfaRegexp',
+        
         # lepl.regexp.unicode
         'UnicodeAlphabet',
+        
+        # lepl.stream.core
+        's_debug', 
+        's_deepest', 
+        's_delta', 
+        's_empty', 
+        's_eq',
+        's_factory', 
+        's_fmt', 
+        's_global_kargs',
+        's_id', 
+        's_join', 
+        's_kargs', 
+        's_key',
+        's_len', 
+        's_line', 
+        's_max', 
+        's_next', 
+        's_stream',
+
         # lepl.stream.maxdepth
         'FullFirstMatchException',
-        # lepl.offside.lexer
-        'Indent',
-        'LineAwareEol',
-        'LineAwareSol',
-        'BIndent',
-        # lepl.offside.matchers
+        
+        # lepl.lexer.lines.matchers
+        'LineStart',
+        'LineEnd',
         'Line',
-        'Block',
-        'BLine',
         'ContinuedLineFactory',
-        'ContinuedBLineFactory',
         'Extend',
-        'SOL',
-        'EOL',
-        'rightmost',
-        'constant_indent'
+        'Block',
+        'NO_BLOCKS',
+        'DEFAULT_POLICY',
+        'explicit',
+        'constant_indent',
+        'to_right',
+        
+        # lepl.support.timer
+        'print_timing'
        ]
 
-__version__ = '4.3.3'
+__version__ = '5.0.1'
 
 if __version__.find('b') > -1:
     from logging import getLogger, basicConfig, WARN
